##  3. Create Relations to Business Capability, Initiative, and Objective
i. In the newly created Strategic Support section, click on the + Add relation button.
ii. Depending on the Fact Sheet type to which the relation is being established, on the right-side panel, fill in the following values to the corresponding fields:
Target Fact Sheet Type | Multiplicity | Section in Target Fact Sheet Type
---|---|---
Business Capability | Many to many | Demand Management
Initiative  | Many to many | Project Environment
Objective  | Many to many | Planning


iii. Click Create
iv. Go to the Manage Translation tab (Globe icon) on the right-side panel, and depending on the Fact Sheet type to which the relation is being established, fill in the following values to the Label and Help Text fields:
| Business Capability | Initiative | Objective
---|---|---|---
Label: | Supports {{targetFactSheets}} | Affected by {{targetFactSheets}} | Supports {{targetFactSheets}}
Help Text (Optional): | Which {{targetFactSheets}} does this {{factSheet}} support? | Which {{targetFactSheets}} are affecting this {{factSheet}}? | Which {{targetFactSheets}} does this {{factSheet}} support?


v. After entering the values, click Show changes, and then Apply to apply the changes.
![Creating relationship to Business Capability Fact Sheet type.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b859e7a441014b574c4ff762d341e_LowRes.gif)
Creating relationship to Business Capability Fact Sheet type.
Relations to Business Capability, Initiative, and Objective Fact Sheet types are created.
